@@ -36,3 +36,7 @@ def init(width, height, font_height, title) -> None:
     global window
     moprint.bind(window)
     moinput.bind(window, moprint)
+
+
+def close() -> None:
+    pygame.event.post(pygame.event.Event(pygame.QUIT))
