@@ -96,13 +96,14 @@ class Console:
         """
         obj = self.data[i][j]
         [x, y] = [j * self.text_width, i * self.text_height]
+        text_width = self.text_width
+        text_height = self.text_height
         if obj.wide:
-            pygame.draw.rect(self.window, obj.back_color, (x, y, self.text_width * 2, self.text_height))
-        else:
-            pygame.draw.rect(self.window, obj.back_color, (x, y, self.text_width, self.text_height))
+            text_width *= 2
+        pygame.draw.rect(self.window, obj.back_color, (x, y, text_width, text_height))
         text = self.font.render(obj.char, True, obj.fore_color, obj.back_color)
-        self.window.blit(text.subsurface(pygame.Rect(0, self.height_offset, self.text_width,
-                                                     self.text_height - self.height_offset * 2)), (x, y))
+        self.window.blit(text.subsurface(pygame.Rect(0, self.height_offset, min(text_width, text.get_width()),
+                                                     text_height - self.height_offset * 2)), (x, y))
 
     def __render_cursor(self) -> None:
         pygame.draw.line(self.window, pygame.color.Color('black') if self.cursor_visible else self.cursor_bkcolor,
